@@ -1,13 +1,19 @@
-# import f4
-# import fastnumbers
-# from joblib import Parallel, delayed
-# import math
-# import zstandard
+print("got here - Builder - 1")
+import f4
+import fastnumbers
+from joblib import Parallel, delayed
+import math
+import zstandard
+print("got here - Builder - 2")
 
 class Builder:
     def __init__(self, verbose=False):
         self.__verbose = verbose
 
+    #TODO
+    def testme(self):
+        print("testme function")
+
     def convert_delimited_file(self, delimited_file_path, f4_file_path, index_columns=[], delimiter="\t", comment_prefix="#", compression_type=None, num_processes=1, num_cols_per_chunk=None, num_rows_per_write=100, tmp_dir_path=None):
         if type(delimiter) != str:
             raise Exception("The delimiter value must be a string.")
