@@ -1,8 +1,8 @@
-# import f4
-# import fastnumbers
-# import operator
-# import os
-# import re
+import f4
+import fastnumbers
+import operator
+import os
+import re
 
 """
 This class is used to indicate that no filtering should be performed.
