@@ -1,9 +1,9 @@
-# import f4
-# import fastnumbers
-# from itertools import chain
-# from joblib import Parallel, delayed
-# import math
-# import operator
+import f4
+import fastnumbers
+from itertools import chain
+from joblib import Parallel, delayed
+import math
+import operator
 
 class IndexSearcher:
     def _get_identifier_row_index(parser, query_value, end_index, data_prefix=""):
