@@ -1,10 +1,10 @@
-# import f4
-# import fastnumbers
-# import glob
-# from itertools import chain
-# from joblib import Parallel, delayed
-# import math
-# import sys
+import f4
+import fastnumbers
+import glob
+from itertools import chain
+from joblib import Parallel, delayed
+import math
+import sys
 
 class Parser:
     """
