@@ -1,4 +1,9 @@
+print("Attempting f4 import")
 import f4
+print("Successful f4 import")
+import sys
+sys.exit()
+
 import glob
 import gzip
 from io import TextIOWrapper, BytesIO
